==> breeze_website_builder_5.4.44.tar.gz: manage/version.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 5/6/2010	ELL
//	Revised: 2/10/2012	ELL
//  Added table prefix handling.
	
	define('VERSION', "5.4.44");
	define('VER_DATE',  "10 jan 2015 01:00:00");	// Release date of this version.
	define('LAST_VER_DATE',  "7 jan 2015 01:00:00");	// Release date of last version.
	
	include ("../connect/db_connect.php");
	include ("../connect/config.php");
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "version`";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$version = $row["version"];
	
	if (VERSION == $version)
		echo "Version $version";
	else
	{
		echo "<script language='JavaScript'  type='text/javascript'>\n";
		
		echo "function MoveWorkspace() {\n";
		echo "document.getElementById('workspace').style.top='170px'\n";
		echo "}\n";
		
		echo "document.getElementById('bwb_version').style.top='5px'\n";
		echo "document.getElementById('bwb_version').style.left='350px'\n";
		echo "document.getElementById('header_divider').style.height='60px'\n";
		echo "document.getElementById('header_divider').style.backgroundColor='#FFFF00'\n";
		echo "document.getElementById('header_divider').style.color='#000000'\n";
		
		echo "var vTimer = setTimeout(function() {MoveWorkspace()}, 1000);\n";
		
		echo "</script>\n";
		echo "<span style='color:#F00;'>\n";
		echo "<br>Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
		echo "Program Files Revision Level: " . VERSION . "<br>\n";
		echo "Database Patch Level: $version<br>\n";
		echo "</span>\n";
	}
?>

==> breeze_website_builder_5.4.54.tar.gz: manage/version.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 5/6/2010	ELL
//	Revised: 2/10/2012	ELL
//  Added table prefix handling.
	
	define('VERSION', "5.4.54");
	define('VER_DATE',  "2 feb 2015 01:00:00");	// Release date of this version.
	define('LAST_VER_DATE',  "22 jan 2015 01:00:00");	// Release date of last version.
	
	include ("../connect/db_connect.php");
	include ("../connect/config.php");
	
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "version`";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$version = $row["version"];
	
	if (VERSION == $version)
		echo "Version $version";
	else
	{
		echo "<script language='JavaScript'  type='text/javascript'>\n";
		
		echo "function MoveWorkspace() {\n";
		echo "document.getElementById('workspace').style.top='170px'\n";
		echo "}\n";
		
		echo "document.getElementById('bwb_version').style.top='5px'\n";
		echo "document.getElementById('bwb_version').style.left='350px'\n";
		echo "document.getElementById('header_divider').style.height='60px'\n";
		echo "document.getElementById('header_divider').style.backgroundColor='#FFFF00'\n";
		echo "document.getElementById('header_divider').style.color='#000000'\n";
		
		echo "var vTimer = setTimeout(function() {MoveWorkspace()}, 1000);\n";
		
		echo "</script>\n";
		echo "<span style='color:#F00;'>\n";
		echo "<br>Your database-revision-patch level does not match your program-files-revision level.  Please contact your system administrator.<br>\n";
		echo "Program Files Revision Level: " . VERSION . "<br>\n";
		echo "Database Patch Level: $version<br>\n";
		echo "</span>\n";
	}
?>
